<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el_GR">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation type="obsolete">Σχετικά με το</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>Συγγραφείς</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>Ένας ελαφρύς περιηγητής ιστοσελίδων βασισμένος στο WebKit</translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="obsolete">&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;p, li { white-space: pre-wrap; }&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <source>WebKit version: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation>Γλώσσες</translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation>Γλώσσες: κατά σειρά προτίμησης:</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Μετακίνηση &amp;Πάνω</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Μετακίνηση &amp;Κάτω</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Αφαίρεση</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation>Προσθήκη...</translation>
    </message>
</context>
<context>
    <name>AdBlockBlockedNetworkReply</name>
    <message>
        <source>Blocked by AdBlockRule: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockDialog</name>
    <message>
        <source>Add Custom Rule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Learn more about writing rules...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse Subscriptions...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AdBlock Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable AdBlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockManager</name>
    <message>
        <source>Custom Rules</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockModel</name>
    <message>
        <source>Rule</source>
        <translation type="unfinished">Κανόνας</translation>
    </message>
</context>
<context>
    <name>AdBlockSchemeAccessHandler</name>
    <message>
        <source>Subscribe?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscribe to this AdBlock subscription?
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>Προσθήκη σελιδοδείκτη</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>Δώστε ένα όνομα και επιλέξτε θέση.</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>Url</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Τίτλος</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Προσθήκη Φακέλου</translation>
    </message>
</context>
<context>
    <name>AutoFillDialog</name>
    <message>
        <source>Form Passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Αφαίρεση</translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillManager</name>
    <message>
        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never for this site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillModel</name>
    <message>
        <source>WebSite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>Άνοιγμα σε Νέα Καρτέλα</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation>Αλλαγή Ονόματος</translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation>Αλλαγή Διεύθυνσης</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Νέος Φάκελος</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>Σελιδοδείκτες</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Αφαίρεση</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>Προσθήκη Φακέλου</translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Bookmarks Bar</source>
        <translation>Μπάρα Σελιδοδεικτών</translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation>Μενού Σελιδοδεικτών</translation>
    </message>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>Σφάλμα φόρτωσης σελιδοδεικτών στη γραμμή %1, στήλη %2:
%3</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>Εργαλειοθήκη Σελιδοδεικτών</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>Μενού</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Άνοιγμα Αρχείου</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml)</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>Εισήχθησαν %1</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Αποθήκευση Αρχείου</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation>%1 Bookmarks.xbel</translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>Σφάλμα εισαγωγής</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>σφάλμα κατά την αποθήκευση σελιδοδεικτών</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>Αφαίρεση Σελιδοδείκτη</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>Εισαγωγή Σελιδοδείκτη</translation>
    </message>
    <message>
        <source>Name Change</source>
        <translation type="obsolete">Αλλαγή Ονόματος</translation>
    </message>
    <message>
        <source>Address Change</source>
        <translation type="obsolete">Αλλαγή Διεύθυνσης</translation>
    </message>
    <message>
        <source>XBEL (*.xbel *.xml *.html)</source>
        <translation type="obsolete">XBEL (*.xbel *.xml *.html)</translation>
    </message>
    <message>
        <source>Error when loading html bookmarks: %1
</source>
        <translation type="obsolete">Σφάλμα κατά τη φόρτωση html σελιδοδεικτών: %1
</translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation type="unfinished">Αλλαγή Ονόματος</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation type="unfinished">Αλλαγή Διεύθυνσης</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation>Άνοιγμα  σε Καρτέλες</translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>Τίτλος</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Διεύθυνση</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">Σελιδοδείκτης</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Άνοιγμα σε Νέα &amp;Καρτέλα</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Αφαίρεση</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Προσθήκη Σελιδοδείκτη...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Προσθήκη Φακέλου...</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">Σελιδοδείκτες</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source> (Change: %1 %2)</source>
        <translation type="obsolete"> (Αλλαγή: %1 %2)</translation>
    </message>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>Είναι ανοιχτά %1 παράθυρα και %2 καρτέλες
Είστε σίγουροι ότι θέλετε να κλείσετε;</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>Η επαναφορά απέτυχε</translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation type="obsolete">Δεν μπορεί να γίνει επαναφορά της αποθηκευμένης συνεδρίας επειδή το Arora τερμάτισε απρόσμενα κατά τη διάρκεια της επαναφοράς.</translation>
    </message>
    <message>
        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Αρχείο</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>&amp;Νέο Παράθυρο</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>Άν&amp;οιγμα Αρχείου...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>Άνοιγμα Τ&amp;οποθεσίας...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>Απο&amp;θήκευση Ως...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>&amp;Εισαγωγή Σελιδοδεικτών...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>Εξαγωγή &amp;Σελιδοδεικτών...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>Π&amp;ροεπισκόπηση Εκτύπωσης...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>Ε&amp;κτύπωση...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>Ασφαλής &amp;Περιήγηση...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Τερματισμός</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Επεξεργασία</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Αναίρεση</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>Α&amp;κύρωση Αναίρεσης</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Αποκο&amp;πή</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>Α&amp;ντιγραφή</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>Επικόλλη&amp;ση</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Ανα&amp;ζήτηση</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>Αναζήτηση Επό&amp;μενου</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>Αναζήτηση Προη&amp;γούμενου</translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation type="obsolete">Προ&amp;τιμήσεις...</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation>Ctrl+,</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Προβολή</translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>Εμφάνιση Γραμμής Μενού</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Shift+Ctrl+B</source>
        <translation type="obsolete">Shift+Ctrl+B</translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation>Ctrl+/</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>&amp;Διακοπή</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>&amp;Επαναφόρτωση</translation>
    </message>
    <message>
        <source>Make Text &amp;Bigger</source>
        <translation type="obsolete">&amp;Μεγέθυνση Γραμματοσειράς</translation>
    </message>
    <message>
        <source>Make Text &amp;Normal</source>
        <translation type="obsolete">Ε&amp;παναφορά Γραμματοσειράς</translation>
    </message>
    <message>
        <source>Make Text &amp;Smaller</source>
        <translation type="obsolete">&amp;Σμίκρυνση Γραμματοσειράς</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>&amp;Κώδικας Σελίδας</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation>Ctrl+Alt+U</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Πλήρης &amp;Οθόνη</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>&amp;Ιστορικό</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Πίσω</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>Μπροστά</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Αρχική Σελίδα</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>Επαναφορά Προηγούμενης Συνεδρίας</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>&amp;Σελιδοδείκτες</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation type="obsolete">Οργάνωση Σελιδοδεικτών...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>Προσθήκη Σελιδοδείκτη...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>Παρά&amp;θυρο</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>Ερ&amp;γαλεία</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>Αναζήτηση στο &amp;Διαδίκτυο</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>&amp;Εκκαθάριση Προσωπικών Δεδομένων</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation>Ctrl+Shift+Delete</translation>
    </message>
    <message>
        <source>Show &amp;Network Monitor</source>
        <translation type="obsolete">Παρακο&amp;λούθηση Δικτύου</translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>Ενε&amp;ργοποίηση του Επόπτη Ιστοσελίδων</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Βοήθεια</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation>Αλλάγη γλώσσας της εφαρμογής</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Σχετικά με το &amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Arora</source>
        <translation type="obsolete">Σχετικά με το &amp;Arora</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Πλοήγηση</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>Εμφάνιση Γραμμής Κατάστασης</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>Απόκρυψη Γραμμής Κατάστασης</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>Εμφάνιση Εργαλειοθήκης</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>Απόκρυψη Εργαλειοθήκης</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>Εμφάνιση Γραμμής Σελιδοδεικτών</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>Απόκρυψη Γραμμής Σελιδοδεικτών</translation>
    </message>
    <message>
        <source>Arora</source>
        <translation type="obsolete">Arora</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>%1 - Arora</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>Άνοιγμα Αρχείου</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Αρχεία Web (*.html *.htm *.svg *.png *.gif *.svgz);;Όλα τα αρχεία (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>Εκτύπωση</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>Είσαι βέβαιος ότι θέλεις να ενεργοποιήσεις την ασφαλή περιήγηση;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Όταν η ασφαλής περιήγηση είναι ενεργή, μερικές λειτουργίες θα απενεργοποιηθούν:&lt;ul&gt;&lt;li&gt; Οι ιστοσελίδες δεν προστίθενται στο ιστορικό.&lt;/li&gt;&lt;li&gt; Τα αντικείμενα που κατεβάζετε, αυτομάτως απομακρύνονται από το παράθυρο λήψης αρχείων.&lt;/li&gt;&lt;li&gt; Δεν αποθηκεύονται νέα cookies και τα ήδη υπάρχοντα είναι αδύνατον να προσπελαστούν.&lt;/li&gt;&lt;li&gt; Το εικονίδια των ιστοσελίδων δεν αποθηκεύονται, η συνεδρία δεν θα αποθηκευτεί.&lt;/li&gt;&lt;li&gt; Το ιστορικό των αναζητήσεων δεν αποθηκεύεται στο πλαίσιο αναζητήσεων.&lt;/li&gt;&lt;/ul&gt;Εώς ότου να κλείσετε το παράθυρο, μπορείτε να κάνετε χρήση των κουμπιών Πίσω και Μπροστά, για να πάτε σε σελίδες που έχει ήδη ανοίξει.</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>Είστε σίγουροι ότι θέλετε να κλείσετε το παράθυρο; Υπάρχουν %1 ανοιχτές καρτέλες</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation>Επόπτης Ιστοσελίδων</translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>Ο επόπτης ιστοσελίδων θα δουλέψει σωστά μόνο για τις σελίδες μετά την ενεργοποίηση του.
Θέλετε να επαναφορτώσετε όλες τις σελίδες;</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>Διακοπή φόρτωσης αυτής της σελίδας</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>Επαναφόρτωση της τρέχουσας σελίδας</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Λήψεις Αρχείων</translation>
    </message>
    <message>
        <source>Alt+Ctrl+L</source>
        <comment>Download Manager</comment>
        <translation type="obsolete">Alt+Ctrl+L</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation>Κλείσιμο Παραθύρου</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>&amp;Μεγέθυνση</translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation>Ε&amp;παναφορά Προβολής</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>&amp;Σμίκρυνση</translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation>Μεγένθυνση &amp;Μόνο Κειμένου</translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation>Σχετικά με το &amp;%1</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;Όταν η ασφαλής περιήγηση είναι ενεργή, μερικές λειτουργίες θα απενεργοποιηθούν:&lt;ul&gt;&lt;li&gt; Οι ιστοσελίδες δεν προστίθενται στο ιστορικό.&lt;/li&gt;&lt;li&gt; Τα αντικείμενα που κατεβάζετε, αυτομάτως απομακρύνονται από το παράθυρο λήψης αρχείων.&lt;/li&gt;&lt;li&gt; Δεν αποθηκεύονται νέα cookies και τα ήδη υπάρχοντα είναι αδύνατον να προσπελαστούν.&lt;/li&gt;&lt;li&gt; Το εικονίδια των ιστοσελίδων δεν αποθηκεύονται, η συνεδρία δεν θα αποθηκευτεί.&lt;/li&gt;&lt;li&gt; Το ιστορικό των αναζητήσεων δεν αποθηκεύεται στο πλαίσιο αναζητήσεων.&lt;/li&gt;&lt;/ul&gt;Εώς ότου να κλείσετε το παράθυρο, μπορείτε να κάνετε χρήση των κουμπιών Πίσω και Μπροστά, για να πάτε σε σελίδες που έχει ήδη ανοίξει.</translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translation>Ctrl+Y</translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation>Εμφάνιση Όλων των Σελιδοδεικτών...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation>Προσθήκη Φακέλου...</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished">Προεπιλογή</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Ad Block...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webpages are not added to the history.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items are automatically removed from the Downloads window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Site icons won&apos;t be stored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session won&apos;t be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searches are not added to the pop-up menu in the search box.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No new network cache is written to disk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Private Browsing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Καθαρισμός</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>Εκκαθάριση Προσωπικών Δεδομένων</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>Εκκαθάριση των ακόλουθων αντικειμένων:</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>&amp;Ιστορικό Περιήγησης</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>Ιστορικό &amp;Λήψης Αρχείων</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>Ιστορικό &amp;Αναζήτησης</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation>&amp;Cookies</translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>&amp;Λανθάνουσα Μνήμη</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>Εικονίδια &amp;Ιστοσελίδων</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>Εκκαθάριση &amp;Προσωπικών Δεδομένων</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Ακύρωση</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>Ιστοσελίδα</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>Κανόνας</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Να επιτρέπεται</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Φραγή</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Να επιτρέπεται μόνο για τη συνεδρία</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>Ιστοσελίδα</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Όνομα</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>Διαδρομή</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>Ασφάλεια</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Λήξη</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>Περιεχόμενα</translation>
    </message>
    <message>
        <source>true</source>
        <translation>αληθές</translation>
    </message>
    <message>
        <source>false</source>
        <translation>ψευδές</translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Απομάκρυνση</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>Απομάκρυνση &amp;Όλων των Cookies</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Εξαιρέσεις Cookies</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>Νέα Εξαίρεση</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>Διεύθυνση:</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>Φραγή</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>Να επιτρέπεται μόνο για τη συνεδρία</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Να επιτρέπεται</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>Εξαιρέσεις</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Απομάκρυνση</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Απομάκρυνση &amp;Όλων</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>Λήψεις Αρχείων</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>Εκκαθάριση λίστας</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0 Αντικείμενα</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="obsolete">&amp;OK</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Φόρμα</translation>
    </message>
    <message>
        <source>Ico</source>
        <translation>Ico</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Όνομα Αρχείου</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>Ξανά Προσπαθήστε</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Διακοπή</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>Αποθήκευση Αρχείου</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>Η μεταφόρτωση ακυρώθηκε: %1</translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>Σφάλμα κατά το άνοιγμα του αρχείου εξόδου: %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>Σφάλμα αποθήκευσης: %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Σφάλμα Δικτύου: %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="obsolete">δευτερόλεπτα</translation>
    </message>
    <message numerus="yes">
        <source>- %n minutes remaining</source>
        <translation type="obsolete">
            <numerusform>- απομένει %n λεπτό</numerusform>
            <numerusform>- απομένουν %n λεπτά</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>- %n seconds remaining</source>
        <translation type="obsolete">
            <numerusform>- απομένει %n δευτερόλεπτο</numerusform>
            <numerusform>- απομένουν %n δευτερόλεπτα</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation type="obsolete">%1 από %2 (%3/δευτ) %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation>;</translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 από %2 - Διακόπηκε</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="obsolete">bytes</translation>
    </message>
    <message>
        <source>kB</source>
        <translation type="obsolete">kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="obsolete">MB</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation>%1 από %2 (%3/δευτ) - %4</translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n Λήψη</numerusform>
            <numerusform>%n Λήψεις</numerusform>
        </translation>
    </message>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation>Είναι %1 λήψεις σε εξέλιξη
Είστε σίγουροι ότι θέλετε να κλείσετε;</translation>
    </message>
    <message numerus="yes">
        <source>%n minutes remaining</source>
        <translation>
            <numerusform>απομένει %n λεπτό</numerusform>
            <numerusform>απομένουν %n λεπτά</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n seconds remaining</source>
        <translation>
            <numerusform>απομένει %n δευτερόλεπτο</numerusform>
            <numerusform>απομένουν %n δευτερόλεπτα</numerusform>
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytes</translation>
    </message>
    <message>
        <source>kB</source>
        <translation>kB</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>GB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>Άνοιγμα</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Αντιγραφή</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Διαγραφή</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Ιστορικό</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>&amp;Απομάκρυνση</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>Α&amp;πομάκρυνση Όλων</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>Προβολή Ιστορικού</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>Εκκαθάριση Ιστορικού...</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>Εκκαθάριση Ιστορικού</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>Θέλετε να διαγράψετε το ιστορικό;</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>Τίτλος</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Διεύθυνση</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>Νωρίτερα Σήμερα</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n αντικείμενο</numerusform>
            <numerusform>%n αντικείμενα</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>Default</source>
        <translation type="obsolete">Προεπιλογή</translation>
    </message>
    <message>
        <source>Choose language</source>
        <translation>Επιλογή γλώσσας</translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation>&lt;p&gt;Μπορείτε να επιλέξετε μια γλώσσα διαφορετική από&lt;br&gt;την προεπιλεγμένη του λειτουργικού συστήματος.&lt;/p&gt;&lt;p&gt;Παρακαλώ επιλέξτε τη γλώσσα που επιθυμείτε&lt;/p&gt;</translation>
    </message>
    <message>
        <source>No translation files are installed.</source>
        <translation type="obsolete">Δεν έχουν εγκατασταθεί αρχεία μεταφράσεων.</translation>
    </message>
    <message>
        <source>No translation files are installed at %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Εισάγετε το όνομα χρήστη και τον κωδικό για &quot;%1&quot; στο %2&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Σύνδεση στον διαμεσολαβητή &quot;%1&quot; χρησιμοποιώντας:&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors?</source>
        <translation type="obsolete">Σφάλματα SSL:

%1

%2

Θέλετε να αγνοήσετε αυτά τα σφάλματα;</translation>
    </message>
    <message>
        <source>Do you want to accept all these certificates?</source>
        <translation type="obsolete">Θέλετε να αποδεχτείτε όλα αυτά τα πιστοποιητικά;</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation>- Σφάλματα SSL</translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Σφάλματα SSL:&lt;br/&gt;&lt;br/&gt;για: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Θέλετε να αγνοήσετε αυτά τα σφάλματα;&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certifactes:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation type="obsolete">&lt;qt&gt;Πιστοποιητικά:&lt;br/&gt;%1&lt;br/&gt;Θέλετε να αποδεχτείτε όλα αυτά τα πιστοποιητικά;&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">Όνομα</translation>
    </message>
    <message>
        <source>Value</source>
        <translation type="obsolete">Τιμή</translation>
    </message>
</context>
<context>
    <name>NetworkMonitorDialog</name>
    <message>
        <source>Network Monitor</source>
        <translation type="obsolete">Παρακολούθηση Δικτύου</translation>
    </message>
    <message>
        <source>Network Requests</source>
        <translation type="obsolete">Αιτήσεις Δικτύου</translation>
    </message>
    <message>
        <source>Request Headers</source>
        <translation type="obsolete">Κεφαλίδες Αίτησης</translation>
    </message>
    <message>
        <source>Response Headers</source>
        <translation type="obsolete">Κεφαλίδες Απάντησης</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">&amp;Αφαίρεση</translation>
    </message>
    <message>
        <source>Remove &amp;All Requests</source>
        <translation type="obsolete">Αφαίρεση &amp;Όλων των Αιτημάτων</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation type="unfinished">Άνοιγμα Αρχείου</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Όνομα</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>Χρειάζεται Αυθεντικοποίηση</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation>DUMMY ICON</translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation>INTRO TEXT DUMMY</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Όνομα Χρήστη:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Κωδικός:</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Δεν Βρέθηκε</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>Αυθεντικοποίηση Διαμεσολαβητή</translation>
    </message>
    <message>
        <source>ICON</source>
        <translation type="obsolete">ICON</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>Σύνδεση σε διαμεσολαβητή</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Όνομα Χρήστη:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Κωδικός:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>Το αρχείο δεν είναι XBEL έκδοσης 1.0.</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>Άγνωστος τίτλος</translation>
    </message>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Redirect: %1</source>
        <translation type="obsolete">Επαναδρομολόγηση: %1</translation>
    </message>
    <message>
        <source>Method</source>
        <translation type="obsolete">Μέθοδος</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="obsolete">Διεύθυνση</translation>
    </message>
    <message>
        <source>Response</source>
        <translation type="obsolete">Απάντηση</translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="obsolete">Μήκος</translation>
    </message>
    <message>
        <source>Content Type</source>
        <translation type="obsolete">Τύπος Περιεχομένου</translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="obsolete">Πληροφορίες</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">Φόρμα</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="obsolete">Ετικέτα</translation>
    </message>
    <message>
        <source>&lt;</source>
        <translation type="obsolete">&lt;</translation>
    </message>
    <message>
        <source>&gt;</source>
        <translation type="obsolete">&gt;</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Ολοκλήρωση</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Αναζήτηση</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Preferences</source>
        <translation>Προτιμήσεις</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Γενικά</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>Στην εκκίνηση του Arora:</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>Προβολή της αρχικής μου σελίδας</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>Προβολή μιας κενής σελίδας</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>Επαναφορά των  παραθύρων και καρτελών που υπήρχαν την  τελευταία φορά</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Αρχική Σελίδα:</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>Χρήση της τρέχουσας</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>Απαλοιφή ιστορικού:</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>Μετά από μια μέρα</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>Μετά από μια εβδομάδα</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>Μετά από δύο εβδομάδες</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>Μετά από ένα μήνα</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>Μετά από ένα χρόνο</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>Χειροκίνητα</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>Κατά την έξοδο από την εφαρμογή</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>Άνοιγμα συνδέσμων από εφαρμογές:</translation>
    </message>
    <message>
        <source>In a tab in the current window</source>
        <translation type="obsolete">Σε καρτέλα στο τρέχον παράθυρο</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>Σε νέο παράθυρο</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Λήψεις Αρχείων</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>Πάντα ερώτηση για την τοποθεσία αποθήκευσης</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>Αποθήκευση αρχείων σε:</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Εμφάνιση</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>Προεπιλεγμένη γραμματοσειρά:</translation>
    </message>
    <message>
        <source>Times 16</source>
        <translation type="obsolete">Times 16</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>Επιλογή...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>Σταθερού πλάτους γραμματοσειρά:</translation>
    </message>
    <message>
        <source>Courier 13</source>
        <translation type="obsolete">Courier 13</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Απόρρητο</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Περιεχόμενο Ιστοσελίδων</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>Ενεργοποίηση Πρόσθετων</translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>Ενεργοποίηση της Javascript</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>Προβολή Εικόνων</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation>Cookies</translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>Αποδοχή Cookies:</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>Πάντα</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Ποτέ</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>Μόνο από σελίδες που μπαίνει ο ίδιος ο χρήστης</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>Εξαιρέσεις...</translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>Διατήρηση Cookies Μέχρι:</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>Να λήξουν</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>Να βγω από την εφαρμογή</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>Το πολύ 90 ημέρες</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation>Cookies...</translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>Καρτέλες</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>Επιλογή καρτελών και παραθύρων καθώς δημιουργούνται</translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs</source>
        <translation type="obsolete">Προειδοποίηση στο κλείσιμο πολλαπλών καρτελών</translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation>Εμφάνισε μόνο ένα κουμπί κλεισίματος αντί για ένα σε κάθε καρτέλα</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>Διαμεσολαβητής</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>Χρήση διαμεσολαβητή</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Τύπος:</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation>Socks5</translation>
    </message>
    <message>
        <source>Http</source>
        <translation type="obsolete">Http</translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>Διαμεσολαβητής:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Θύρα:</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>Όνομα Χρήστη:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Κωδικός:</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Για Προχωρημένους</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>Style Sheet:</translation>
    </message>
    <message>
        <source>Prefered languages for viewing webpages in:</source>
        <translation type="obsolete">Προτιμώμενες γλώσσες για την εμφάνιση των ιστοσελίδων:</translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation>Φραγή Αναδυόμενων Παραθύρων</translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation>Άνοιγμα συνδέσμων</translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation>Συνδέσμους που θέλετε να ανοίξετε σε νέο παράθυρο:</translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation>Σε μια νέα επιλεγμένη καρτέλα στο τρέχον παράθυρο</translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation>Σε μια νέα καρτέλα στο τρέχον παράθυρο</translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation>Στην τρέχουσα καρτέλα</translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation>Http (Ασφαλές)</translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation>Http (Διαφανές)</translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation>Προτιμώμενες γλώσσες για την εμφάνιση των ιστοσελίδων:</translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose Directory...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A cookie session ends:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When I exit the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>30 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill web forms:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User names and passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose CSS File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation>Φορτώνει...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Επεξεργασία</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Αναζήτηση</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="obsolete">&amp;Προβολή</translation>
    </message>
    <message>
        <source>&amp;Wrap lines</source>
        <translation type="obsolete">&amp;Περιορισμός γραμμής κειμένου στο παράθυρο</translation>
    </message>
    <message>
        <source>Source of Page </source>
        <translation type="obsolete">Κώδικας της Σελίδας</translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>Show Tab Bar</source>
        <translation>Εμφάνιση Γραμμής Καρτελών</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>Απόκρυψη Γραμμής Καρτελών</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation type="obsolete">Νέα &amp;Καρτέλα</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>Αντίγραφο Καρτέλας</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>Κ&amp;λείσιμο Καρτέλας</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>Κλ&amp;είσιμο των άλλων Καρτελών</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>Επαναφόρτωση Καρτέλας</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>Επαναφόρτωση όλων των Καρτελών</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>&amp;Νέα Καρτέλα</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>&amp;Κλείσιμο Καρτέλας</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>Προβολή Επόμενης Καρτέλας</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation>Ctrl-]</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>Προβολή Προηγούμενης Καρτέλας</translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation>Ctrl-[</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>Πρόσφατα Κλεισμένες Καρτέλες</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Χωρίς τίτλο</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>Θέλετε σίγουρα να κλείσετε αυτή τη σελίδα;</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>Έχετε τροποποιήσει τη σελίδα και μόλις την κλείσετε θα χάσετε τις αλλαγές.
Θέλετε σίγουρα να κλείσετε αυτή τη σελίδα;
</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Φορτώνει...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation>Φορτώνει %1% (%2 %3)...</translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation>Ολοκλήρωση φόρτωσης</translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation>Αποτυχία φόρτωσης</translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation>[Όνομα Φακέλου]</translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation>Όλες οι Καρτέλες ως Σελιδοδείκτης</translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Recent Searches</source>
        <translation>Δεν Υπάρχουν Πρόσφατες Αναζητήσεις</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>Πρόσφατες Αναζητήσεις</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation type="unfinished">Απαλοιφή Πρόσφατων Αναζητήσεων</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation>Προτάσεις</translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>Σφάλμα κατά την φόρτωση της σελίδας: %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation>Κατά τη σύνδεση στο: %1.</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation>Έλεγξε την διεύθυνση για λάθη όπως &lt;b&gt;ww&lt;/b&gt;.arora-browser.org αντί για &lt;b&gt;www&lt;/b&gt;.arora-browser.org</translation>
    </message>
    <message>
        <source>If the address is correct, try to check the network connection.</source>
        <translation type="obsolete">Εάν η διεύθυνση είναι σωστή, ελέγξτε την σύνδεση σας.</translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation>Εάν ο υπολογιστής σας ή το δίκτυο σας προστατεύεται από τείχος προστασίας ή διαμεσολαβητή, βεβαιωθείται ότι ο περιηγητής σας έχει τα κατάλληλα δικαιώματα για πρόσβαση στο δίκτυο.</translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation>Εάν η διεύθυνση είναι σωστή, ελέγξτε την σύνδεση σας.</translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>Άνοιγμα σε Νέο &amp;Παράθυρο</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>Άνοιγμα σε Νέα  &amp;Καρτέλα</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>Αποθήκευση &amp;Δεσμού</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>Ο Δεσμός ως &amp;Σελιδοδείκτης</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>&amp;Αντιγραφή Τοποθεσίας Δεσμού</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>Προβολή Εικόνας σε Νέο &amp;Παράθυρο</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>Προβολή Εικόνας σε Νέα &amp;Καρτέλα</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>&amp;Αποθήκευση Εικόνας</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>Αντιγραφή &amp;Εικόνας</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>Αντιγραφή &amp;Τοποθεσίας Εικόνας</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>Φορτώνει...</translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>Δεν Βρέθηκε</translation>
    </message>
</context>
</TS>
